aboutsummaryrefslogtreecommitdiffstats
path: root/src/module/system/Event.cpp
diff options
context:
space:
mode:
Diffstat (limited to '')
-rw-r--r--src/module/system/Event.cpp (renamed from src/plugin/system/Event.cpp)4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/plugin/system/Event.cpp b/src/module/system/Event.cpp
index b899e7e3..3e27e26d 100644
--- a/src/plugin/system/Event.cpp
+++ b/src/module/system/Event.cpp
@@ -30,7 +30,7 @@
#include <memory>
-namespace GpgFrontend::Plugin {
+namespace GpgFrontend::Module {
class Event::Impl {
public:
@@ -105,4 +105,4 @@ void Event::AddParameter(const std::string& key, const ParameterValue& value) {
p_->AddParameter(key, value);
}
-} // namespace GpgFrontend::Plugin \ No newline at end of file
+} // namespace GpgFrontend::Module \ No newline at end of file